@@ -1,11 +1,11 @@
 # -*- perl -*-
 ##----------------------------------------------------------------------------
 ## Database Object Interface - ~/lib/DB/Object/Mysql.pm
-## Version v0.3.5
-## Copyright(c) 2021 DEGUEST Pte. Ltd.
+## Version v0.3.6
+## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2017/07/19
-## Modified 2022/11/04
+## Modified 2022/11/11
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -26,7 +26,7 @@ BEGIN
     die( $@ ) if( $@ );
     use Nice::Try;
     # DBI->trace( 5 );
-    $VERSION = 'v0.3.5';
+    $VERSION = 'v0.3.6';
     use Devel::Confess;
 };
 
@@ -441,7 +441,7 @@ sub _dsn
     my @params = ( sprintf( 'dbi:%s:database=%s', @$self{ qw( driver database ) } ) );
     if( $self->{host} )
     {
-        $self->_load_class( 'Net::IP' ) || return( $sef->pass_error );
+        $self->_load_class( 'Net::IP' ) || return( $self->pass_error );
         my $ip = Net::IP->new( $self->{host} );
         if( $ip )
         {
@@ -595,7 +595,7 @@ DB::Object::Mysql - Mysql Database Object
     
 =head1 VERSION
 
-    v0.3.5
+    v0.3.6
 
 =head1 DESCRIPTION
 
